default_app_config = "django_crontab_manager.apps.DjangoCrontabManagerConfig"

app_requires = [
    "django_fastadmin",
    "django_apiview",
    "django_simple_export_admin",
    "django_data_import_management",
]
